"""
    Factiva Core Auth Module
"""
__all__ = ['userkey', 'UserKey']

from .userkey import (UserKey)
